/**********************************************************************
 * SCIDYNE Corporation  https://scidyne.com   
 * 
 * Demonstrate DIO24-ARD library routines portWrite() and portRead(). 
 *  
 * This program is Open-Source software. It is distributed  
 * WITHOUT ANY WARRANTY of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You can redistribute and/or modify it under the terms of the MIT License. 
 * See the license.txt file for complete details and additional provisions.
 * 
 * Written by Mark Durgin  11/22/22  Version 1.0.0
 * 
 * The bits of portB are continuously toggled using an 8-bit counter.  
 * Results of port reads are displayed on the Arduino IDE Serial Monitor.
 * Connect any channels of portA to ground to make changes in displayed data.
 **********************************************************************/

/***************************************************************
 * Instantiate the DIO24-ARD library
 */ 
#include <SCIDYNE_DIO24ARD.h>
SCIDYNE_DIO24ARD DIO24ARD;    

void setup()
{ 
  /**************************************************************  
   *  Setup the DIO24-ARD board and library software
   *  - Arduino digital I/O #10 used as DIO24-ARD select on SPI bus
   *  - The portA channels configured as inputs, portB and portC configured as outputs
   */
  DIO24ARD.setup(10, 0x00, 0xFF, 0xFF);  // pin#10, portA_DDR, portB_DDR, portC_DDR

  // Initialize serial communications for Serial Monitor
  Serial.begin(115200);
}

void loop()
{
  uint8_t counter = 0x00;                        // An 8-bit counter initialized to 0x00
  uint8_t portA_data, portB_data, portC_data;    // Will hold the port data after a read
  
  while(1)
  {  
    // Continuously toggle the bits of portB by echoing the 8-bit counter value. 
    DIO24ARD.portWrite(1, counter);      // Write portB with counter value
    counter++;                           // Increment the 8-bit counter

    // Read the three ports 
    portA_data = DIO24ARD.portRead(0);   // Read and store portA data
    portB_data = DIO24ARD.portRead(1);   // Read and store portB data
    portC_data = DIO24ARD.portRead(2);   // Read and store portC data
  
    // Send the port data to the serial monitor. 
    // Note: Open the Serial Monitor in the Arduino IDE to view.
    Serial.print(F("PortA: "));          // Display portA
    Serial.println(portA_data,HEX);
    
    Serial.print(F("PortB: "));          // Display portB
    Serial.println(portB_data,HEX);
  
    Serial.print(F("PortC: "));          // Display portC
    Serial.println(portC_data,HEX);

    Serial.println();
  }
}
