/**********************************************************************
 * SCIDYNE Corporation  https://scidyne.com   
 * 
 * Demonstrate DIO24-ARD library routines readBit()
 *  
 * This program is Open-Source software. It is distributed  
 * WITHOUT ANY WARRANTY of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You can redistribute and/or modify it under the terms of the MIT License. 
 * See the license.txt file for complete details and additional provisions.
 * 
 * Written by Mark Durgin  11/22/22  Version 1.0.0
 * 
 * Illustrates how to read digital bits. Connect any channel 7:0 (portA) 
 * to ground to make changes in displayed data. The DIO24-ARD circuitry
 * performs inversion, grounding an input causes a "1" to be displayed.
 **********************************************************************/

/***************************************************************
 * Instantiate the DIO24-ARD library
 */ 
#include <SCIDYNE_DIO24ARD.h>
SCIDYNE_DIO24ARD DIO24ARD;    

void setup()
{
  /**************************************************************  
   *  Setup the DIO24-ARD board and library
   *  - Arduino digital I/O #10 designated as DIO24-ARD select on SPI bus
   *  - Configure DIO24-ARD channels 7:0 (portA) as inputs and all others as outputs.
   */
  DIO24ARD.setup(10, 0x00, 0xFF, 0xFF);  // pin#10, portA_DDR, portB_DDR, portC_DDR

  // Initialize serial communications for Serial Monitor
  Serial.begin(115200);
}

void loop()
{
  /***************************************************************
   * Send the state of channels 7:0 (portA) to the Serial Monitor
   * Note: Open the Serial Monitor in the Arduino IDE to view.
   */

  Serial.print(F("Channel-0: "));  Serial.println(DIO24ARD.readBit(0),BIN);
  Serial.print(F("Channel-1: "));  Serial.println(DIO24ARD.readBit(1),BIN);
  Serial.print(F("Channel-2: "));  Serial.println(DIO24ARD.readBit(2),BIN);
  Serial.print(F("Channel-3: "));  Serial.println(DIO24ARD.readBit(3),BIN);
  Serial.print(F("Channel-4: "));  Serial.println(DIO24ARD.readBit(4),BIN);
  Serial.print(F("Channel-5: "));  Serial.println(DIO24ARD.readBit(5),BIN);
  Serial.print(F("Channel-6: "));  Serial.println(DIO24ARD.readBit(6),BIN);
  Serial.print(F("Channel-7: "));  Serial.println(DIO24ARD.readBit(7),BIN);
  
  Serial.println(F("------------"));
  delay(500);  // Delay added to slow down serial monitor screen scroll
}
