/**********************************************************************
 * SCIDYNE Corporation  https://scidyne.com  
 * 
 * Demonstrate DIO24-ARD library routines writeDDR() and readDDR()
 *  
 * This program is Open-Source software. It is distributed  
 * WITHOUT ANY WARRANTY of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You can redistribute and/or modify it under the terms of the MIT License. 
 * See the license.txt file for complete details and additional provisions.
 * 
 * Written by Mark Durgin  11/22/22  Version 1.0.0
 * 
 * Illustrates how port Data Directions can be changed after instantiation.
 **********************************************************************/

/***************************************************************
 * Instantiate the DIO24-ARD library
 */ 
#include <SCIDYNE_DIO24ARD.h>
SCIDYNE_DIO24ARD DIO24ARD;    

void setup()
{
  /**************************************************************  
   *  Setup the DIO24-ARD board and library
   *  - Arduino digital I/O #10 designated as DIO24-ARD select on SPI bus
   *  - Initially configure all DIO24-ARD channels as input-only
   */
  DIO24ARD.setup(10, 0x00, 0x00, 0x00);  // pin#10, portA_DDR, portB_DDR, portC_DDR

  // Initialize serial communications for Serial Monitor
  Serial.begin(115200);
}

void loop()
{
  /***************************************************************
   * Send the ports Data Directions to the Serial Monitor
   * Note: Open the Serial Monitor in the Arduino IDE to view.
   */
   Serial.println(F("Initial Data Directions"));
   
   Serial.print(F("PortA_DDR: "));          // Display portA Data Direction
   Serial.println(DIO24ARD.readDDR(0),HEX);
    
   Serial.print(F("PortB_DDR: "));          // Display portB Data Direction
   Serial.println(DIO24ARD.readDDR(1),HEX);
  
   Serial.print(F("PortC_DDR: "));          // Display portC Data Direction
   Serial.println(DIO24ARD.readDDR(2),HEX);

   Serial.println();

  /***************************************************************
   * Change the Data Direction of portB to all outputs. The 
   * Data Direction of portA and PortC are unaffected and remain
   * configured as input-only.
   */
   DIO24ARD.writeDDR(1, 0xFF);

  /***************************************************************
   * Send the new ports Data Directions to the Serial Monitor
   */
   Serial.println(F("New Data Directions"));
   
   Serial.print(F("PortA_DDR: "));          // Display portA Data Direction
   Serial.println(DIO24ARD.readDDR(0),HEX);
    
   Serial.print(F("PortB_DDR: "));          // Display portB Data Direction
   Serial.println(DIO24ARD.readDDR(1),HEX);
  
   Serial.print(F("PortC_DDR: "));          // Display portC Data Direction
   Serial.println(DIO24ARD.readDDR(2),HEX);

   Serial.println();

   while(1);  // Loop here forever. Press board reset to repeat program
}
